@@ -45,23 +45,31 @@ USA. */
 # define __END_DECLS /* empty */
 #endif
 
-/* __P is a macro used to wrap function prototypes, so that compilers
+/* LTDL_PARAMS is a macro used to wrap function prototypes, so that compilers
    that don't understand ANSI C prototypes still work, and ANSI C
    compilers can issue warnings about type mismatches. */
-#undef __P
+#undef LTDL_PARAMS
 #if defined (__STDC__) || defined (_AIX) || (defined (__mips) && defined (_SYSTYPE_SVR4)) || defined(__CYGWIN32__) || defined(__cplusplus)
-# define __P(protos) protos
+# define LTDL_PARAMS(protos) protos
 # define lt_ptr_t     void*
 #else
-# define __P(protos) ()
+# define LTDL_PARAMS(protos) ()
 # define lt_ptr_t     char*
 #endif
 
 #ifdef __CYGWIN32__
-#  ifdef _LIBFOO_COMPILATION_
-#    define EXTERN __declspec(dllexport)
+#  ifdef LIBFOO_DLL
+     /* need some (as yet non-existant) automake magic to tell
+      * the object whether the libfoo it will be linked with is
+      * a dll or not, ie whether LIBFOO_DLL is defined or not.
+      */
+#    ifdef _LIBFOO_COMPILATION_
+#      define EXTERN __declspec(dllexport)
+#    else
+#      define EXTERN extern __declspec(dllimport)
+#    endif
 #  else
-#    define EXTERN extern __declspec(dllimport)
+#    define EXTERN extern
 #  endif
 #else
 #  define EXTERN extern
@@ -74,8 +82,8 @@ USA. */
 
 /* Declarations.  Note the wonderful use of the above macros. */
 __BEGIN_DECLS
-int foo __P((void));
-int hello __P((void));
+int foo LTDL_PARAMS((void));
+int hello LTDL_PARAMS((void));
 EXTERN int nothing;
 __END_DECLS
 
